// PIC16F1827 Configuration Bit Settings

// 'C' source line config statements

#include <xc.h>

// #pragma config statements should precede project file includes.
// Use project enums instead of #define for ON and OFF.

// CONFIG1
#pragma config FOSC = INTOSC    // Oscillator Selection (INTOSC oscillator: I/O function on CLKIN pin)
#pragma config WDTE = OFF       // Watchdog Timer Enable (WDT disabled)
#pragma config PWRTE = ON       // Power-up Timer Enable (PWRT enabled)
#pragma config MCLRE = OFF      // MCLR Pin Function Select (MCLR/VPP pin function is digital input)
#pragma config CP = OFF         // Flash Program Memory Code Protection (Program memory code protection is disabled)
#pragma config CPD = OFF        // Data Memory Code Protection (Data memory code protection is disabled)
#pragma config BOREN = ON       // Brown-out Reset Enable (Brown-out Reset enabled)
#pragma config CLKOUTEN = OFF   // Clock Out Enable (CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin)
#pragma config IESO = OFF       // Internal/External Switchover (Internal/External Switchover mode is disabled)
#pragma config FCMEN = OFF      // Fail-Safe Clock Monitor Enable (Fail-Safe Clock Monitor is disabled)

// CONFIG2
#pragma config WRT = OFF        // Flash Memory Self-Write Protection (Write protection off)
#pragma config PLLEN = OFF      // PLL Enable (4x PLL disabled)
#pragma config STVREN = OFF     // Stack Overflow/Underflow Reset Enable (Stack Overflow or Underflow will not cause a Reset)
#pragma config BORV = LO        // Brown-out Reset Voltage Selection (Brown-out Reset Voltage (Vbor), low trip point selected.)
#pragma config LVP = OFF        // Low-Voltage Programming Enable (High-voltage on MCLR/VPP must be used for programming)

#define _XTAL_FREQ  8000000   // delay用(クロック8MHzで動作時)

unsigned char seccnt;//１秒カウンタ

//割り込み処理
void interrupt intr(void) {
    T0IF = 0;//TMR0割り込みクリア
    seccnt--;//割り込みが掛かる度に１つ減らす
}

// メインの処理関数
void main(){

    OSCCON = 0b01110010;//内部クロック8MHz
    ANSELA = 0b00000000;//全てデジタルI/O
    ANSELB = 0b00000000;//全てデジタルI/O
    TRISA  = 0b00000000;//全て出力(RA5は入力のみ)
    TRISB  = 0b00100000;//RB5のみ入力
    APFCON0bits.SS1SEL = 1;//SS1 function is on RA5 not RB5
    APFCON1bits.TXCKSEL = 0;//TX/CK function is on RB2 not RB5

    GIE = 1;//全体割り込み許可
    OPTION_REG = 0b10000111;//プリスケーラ:256
    TMR0 = 0x00;//256数える
    T0IE = 0;//TMR0割り込み許可

    while(1){
        if(PORTBbits.RB5 == 1){
            PORTAbits.RA0 = 1;//LED点灯
            while(PORTBbits.RB5 == 1){//暗いままならとどまる
            };
            seccnt = 244;//Timer0用のカウンタ(約８秒)
            T0IE = 1;//Timer0スタート
            while(seccnt > 0){//カウント中ならとどまる
            };
            T0IE = 0;//Timer0終了
        }else{
            PORTAbits.RA0 = 0;//LED消灯
        }
    }
}